==> TundereBird-0.24.tar.bz2: TundereBird-0.24/core/Smdn.Net.Imap4.Client/Smdn.Net.Imap4.Client.Transaction.BuiltIn/NoOpTransactionBase.cs <==
// 
// Author:
//       smdn <smdn@mail.invisiblefulmoon.net>
// 
// Copyright (c) 2008-2010 smdn
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using System.Collections.Generic;

using Smdn.Net.Imap4.Protocol.Client;

namespace Smdn.Net.Imap4.Client.Transaction.BuiltIn {
  internal abstract class NoOpTransactionBase : ImapTransactionBase {
    protected NoOpTransactionBase(string command, ImapConnection connection)
      : base(connection)
    {
      commandString = command;
    }

    protected override ProcessTransactionDelegate Reset()
    {
      return ProcessNoOp;
    }

    // 6.1.2. NOOP Command
    //    Arguments:  none
    //    Responses:  no specific responses for this command (but see below)
    //    Result:     OK - noop completed
    //                BAD - command unknown or arguments invalid
    //       Since any command can return a status update as untagged data, the
    //       NOOP command can be used as a periodic poll for new messages or
    //       message status updates during a period of inactivity (this is the
    //       preferred method to do this).
    //
    //    Example:    C: a002 NOOP
    //                S: a002 OK NOOP completed
    //                   . . .
    //                C: a047 NOOP
    //                S: * 22 EXPUNGE
    //                S: * 23 EXISTS
    //                S: * 3 RECENT
    //                S: * 14 FETCH (FLAGS (\Seen \Deleted))
    //                S: a047 OK NOOP completed

    // 6.4.1. CHECK Command
    //    Arguments:  none
    //    Responses:  no specific responses for this command
    //    Result:     OK - check completed
    //                BAD - command unknown or arguments invalid
    //
    //       There is no guarantee that an EXISTS untagged response will happen
    //       as a result of CHECK.  NOOP, not CHECK, SHOULD be used for new
    //       message polling.
    private void ProcessNoOp()
    {
      SendCommand(commandString, ProcessReceiveResponse);
    }

    private /*readonly*/ string commandString;
  }
}

==> TundereBird-0.28.tar.bz2: TundereBird-0.28/core/Smdn.Net.Imap4.Client/Smdn.Net.Imap4.Client.Transaction.BuiltIn/NoOpTransactionBase.cs <==
// 
// Author:
//       smdn <smdn@mail.invisiblefulmoon.net>
// 
// Copyright (c) 2008-2010 smdn
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using System.Collections.Generic;

using Smdn.Net.Imap4.Protocol.Client;

namespace Smdn.Net.Imap4.Client.Transaction.BuiltIn {
  internal abstract class NoOpTransactionBase : ImapTransactionBase {
    protected NoOpTransactionBase(ImapConnection connection)
      : base(connection)
    {
    }

    protected override ProcessTransactionDelegate Reset()
    {
      return ProcessNoOp;
    }

    // 6.1.2. NOOP Command
    //    Arguments:  none
    //    Responses:  no specific responses for this command (but see below)
    //    Result:     OK - noop completed
    //                BAD - command unknown or arguments invalid
    //       Since any command can return a status update as untagged data, the
    //       NOOP command can be used as a periodic poll for new messages or
    //       message status updates during a period of inactivity (this is the
    //       preferred method to do this).
    //
    //    Example:    C: a002 NOOP
    //                S: a002 OK NOOP completed
    //                   . . .
    //                C: a047 NOOP
    //                S: * 22 EXPUNGE
    //                S: * 23 EXISTS
    //                S: * 3 RECENT
    //                S: * 14 FETCH (FLAGS (\Seen \Deleted))
    //                S: a047 OK NOOP completed

    // 6.4.1. CHECK Command
    //    Arguments:  none
    //    Responses:  no specific responses for this command
    //    Result:     OK - check completed
    //                BAD - command unknown or arguments invalid
    //
    //       There is no guarantee that an EXISTS untagged response will happen
    //       as a result of CHECK.  NOOP, not CHECK, SHOULD be used for new
    //       message polling.
    private void ProcessNoOp()
    {
      if (this is NoOpTransaction)
        SendCommand("NOOP", ProcessReceiveResponse);
      else if (this is CheckTransaction)
        SendCommand("CHECK", ProcessReceiveResponse);
    }
  }
}
